"""MongoDB based message queue using pymongo"""

__version__ = '1.1.0'
__url__ = 'https://github.com/discogs/pymongo-job-queue'
__author__ = 'Andy Craze'
__email__ = 'acraze@discogsinc.com'

from jobqueue import JobQueue
